==> caer-1.7.2.tar.gz: caer-1.7.2/README.md <==
# Caer: Computer Vision in Python, built for Humans
A Computer Vision library in Python with powerful image processing operations, including support for Deep Learning models built using the Keras framework

[![Python](https://img.shields.io/pypi/pyversions/caer.svg?style=plastic)](https://pypi.org/project/caer/)
[![PyPI](https://badge.fury.io/py/caer.svg)](https://pypi.org/project/caer/)

[![Downloads](https://pepy.tech/badge/caer)](https://pepy.tech/project/caer)
[![license](https://img.shields.io/github/license/mashape/apistatus.svg?maxAge=2592000)](https://github.com/jasmcaus/caer/blob/master/LICENSE)

## Installation
The `caer` package can be installed via a simple pip install command 

<pre>$ pip install caer</pre>

## Resources

- **Homepage:** <https://github.com/jasmcaus/caer/>
- **PyPi:** <https://pypi.org/project/caer/>
- **Docs:** <https://github.com/jasmcaus/caer/blob/master/DOCS.md>
- **Issue tracking:** <https://github.com/jasmcaus/caer/issues>

## Contribution Guidelines

If you have improvements to `caer`, send us your pull requests! We'd love to accept your patches! We strongly encourage you to go through the [Contribution Guidelines](CONTRIBUTING.md)

One of our maintainers will be assigned to review your pull requests. Once the pull requests are approved and pass continuous integration checks, a `ready to pull` label will be applied to your change. This means we are working on getting your pull request submitted to our internal repository. Once the change has been submitted internally, your pull request will be merged automatically on GitHub.

If you want to contribute, start working through the `caer` codebase, navigate to the
[Issues](https://github.com/jasmcaus/caer/issues) tab and start looking through interesting issues. 

## License

[MIT License](https://github.com/jasmcaus/caer/blob/master/LICENSE)

==> caer-1.7.5.tar.gz: caer-1.7.5/README.md <==
# Caer: Computer Vision in Python, built for Humans
A Computer Vision library in Python with powerful image and video processing operations.

[![Python](https://img.shields.io/pypi/pyversions/caer.svg?style=plastic)](https://pypi.org/project/caer/)
[![PyPI](https://badge.fury.io/py/caer.svg)](https://pypi.org/project/caer/)

[![Downloads](https://pepy.tech/badge/caer)](https://pepy.tech/project/caer)
[![license](https://img.shields.io/github/license/mashape/apistatus.svg?maxAge=2592000)](https://github.com/jasmcaus/caer/blob/master/LICENSE)

## Installation
The `caer` package can be installed via a simple pip install command 

```shell
$ pip install caer
```

You can run the following to verify things installed correctly:

```python
import caer

print(f'Caer version {caer.__version__}')
```

## Resources

- **Homepage:** <https://github.com/jasmcaus/caer/>
- **PyPi:** <https://pypi.org/project/caer/>
- **Docs:** <https://github.com/jasmcaus/caer/blob/master/DOCS.md>
- **Issue tracking:** <https://github.com/jasmcaus/caer/issues>

## Contribution Guidelines

If you have improvements to `caer`, send us your pull requests! We'd love to accept your patches! We strongly encourage you to go through the [Contribution Guidelines](CONTRIBUTING.md)

One of our maintainers will be assigned to review your pull requests. Once the pull requests are approved and pass continuous integration checks, a `ready to pull` label will be applied to your change. This means we are working on getting your pull request submitted to our internal repository. Once the change has been submitted internally, your pull request will be merged automatically on GitHub.

If you want to contribute, start working through the `caer` codebase, navigate to the
[Issues](https://github.com/jasmcaus/caer/issues) tab and start looking through interesting issues. 

## License

Caer is released under the [MIT License](https://github.com/jasmcaus/caer/blob/master/LICENSE)
